@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
 """Stats representation of evergreen."""
-from __future__ import absolute_import, annotations
+from __future__ import absolute_import
 
 from typing import Any, Dict, TYPE_CHECKING
 
@@ -28,7 +28,7 @@ class TaskReliability(_BaseEvergreenObject):
     avg_duration_pass = evg_attrib("avg_duration_pass")
     success_rate = evg_attrib("success_rate")
 
-    def __init__(self, json: Dict[str, Any], api: EvergreenApi) -> None:
+    def __init__(self, json: Dict[str, Any], api: "EvergreenApi") -> None:
         """
         Create an instance of a test stats object.
 
